package beilv.admissionticket.service;

import beilv.admissionticket.domain.AdmissionTicket;
import beilv.common.core.domain.AjaxResult;

import java.util.List;
import java.util.Map;

public interface IAdmissionTicketService {
    int insertAdmissionTicketToList(List<AdmissionTicket> ticketList);

    /**
     * 查询约球购票
     *
     * @param id 约球购票主键
     * @return 约球购票
     */
    public AdmissionTicket selectBeilvAdmissionTicketById(String id);

    /**
     * 查询约球购票列表
     *
     * @param AdmissionTicket 约球购票
     * @return 约球购票集合
     */
    public List<AdmissionTicket> selectBeilvAdmissionTicketList(AdmissionTicket AdmissionTicket);

    /**
     * 新增约球购票
     *
     * @param AdmissionTicket 约球购票
     * @return 结果
     */
    public int insertBeilvAdmissionTicket(AdmissionTicket AdmissionTicket);

    /**
     * 修改约球购票
     *
     * @param AdmissionTicket 约球购票
     * @return 结果
     */
    public int updateBeilvAdmissionTicket(AdmissionTicket AdmissionTicket);

    /**
     * 批量删除约球购票
     *
     * @param ids 需要删除的约球购票主键集合
     * @return 结果
     */
    public int deleteBeilvAdmissionTicketByIds(String ids);

    /**
     * 删除约球购票信息
     *
     * @param id 约球购票主键
     * @return 结果
     */
    public int deleteBeilvAdmissionTicketById(String id);

    void updateTicketStatus(List<String> ids, String ticketStatus);

    Map<String, Object> getThresholdValue(String ticketId);

    int confirm(AdmissionTicket beilvAdmissionTicket);

    void createTask(AdmissionTicket AdmissionTicket);

    AjaxResult refund(AdmissionTicket beilvAdmissionTicket);
}
